/* emacs: -*- Mode: C; c-style: "bsd"; c-basic-offset: 4; c-recognize-knr-p: nil; -*- */

#include <qmime.h>
#include <qprocess.h>

#include "aboutdialog.h"
#include "version.h"
#include "settings.h"
#include "mainwindow.h"

extern Main *mainWindow;
extern Settings settings;

AboutDialog::AboutDialog( QWidget *parent, const char *name)
    : QDialog( parent, name)
{
 
    mainLayout=new QVBoxLayout( this, 10);

    tabs=new QTabWidget (this);
    credits=new AboutTextBrowser (this,"credits");

    credits->setText (
	"<h3><img src=\"vym_logo\">VYM - View Your Mind </h3>"
	"<p> A tool to put the things you have got in your mind into a map.</p>"
	"<ul>"
	"<li> (c) by Uwe Drechsel (<a href=\"mailto:vym@InSilmaril.de\">vym@InSilmaril.de</a>)</li>"
	"<li> vym is released under the GPL (Gnu General Public License)"
	", with one exception (see the file \"LICENSE\"which "
	"comes with vym). This exception is needed to build vym with QT libraries for proprietary operating systems.</li>"
	"<li> Project homepage <a href=\"http:/www.InSilmaril.de/vym\">"
	"http://www.InSilmaril.de/vym</a></li>"
	"<li> Credits " 
	"<ul>"
	"<li>Jakob Hilmer for image drag and drop patch </li>"
	"<li>Thomas Schraitle for the stylesheet  used for XHTML-export </li>"
	"<li>Clemens Kraus for stylesheets and script used for HTML-export "
	"<a href=\"http://www.clemens-kraus.de\">(www.clemens-kraus.de)</a></li>"
	"<li>Alexander Johannesen for providing stylesheets from his xsiteable project " 
	"<a href=\"http://www.shelter.nu/xsiteable/xsiteable.html\">(www.shelter.nu/xsiteable/xsiteable.html)</a>. </li>"
	"<li>Ken Wimer and Olaf Hering for Mac support</li>"
	"</ul>"
	"</li>");
    credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
    tabs->addTab (credits,"Credits");

    license=new AboutTextBrowser (this,"license");
    license->setText ("License text...");
    credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
    tabs->addTab (license,"License");

    mainLayout->addWidget (tabs);
    tabs->showPage (credits);

    okbutton =new QPushButton (this,"okbutton");
    okbutton->setText (tr("Ok"));
    okbutton->setMaximumSize (QSize (50,30));
    okbutton->setAutoDefault (true);
    mainLayout->addWidget( okbutton); 

    connect( okbutton, SIGNAL( clicked() ), this, SLOT( accept() ) );
}

AboutTextBrowser::AboutTextBrowser(QWidget *parent, const char *name)
    : QTextBrowser(parent, name)
{
    
}

void AboutTextBrowser::setSource(const QString &name)
{
    QMimeSourceFactory *factory = QMimeSourceFactory::defaultFactory();
    const QMimeSource *data = factory->data(name);
    if (data) {
	QTextBrowser::setSource(name);
    } else {
	QProcess *proc = new QProcess( this );
	proc->addArgument( settings.readEntry("/vym/mainwindow/readerURL" ));
	proc->addArgument( name);
	
	if ( !proc->start() ) 
	    if (mainWindow->settingsURL() ) 
		setSource(name);
    }
}
